# Change Log

The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [Unreleased]
### Added
- ...

### Changed
- ...

## [0.1.1] - 2017-01-23
### Added
- [docs] changelog added

## [0.1.0] - 2017-01-23
### Added
- [find] parse the index and generate the .repos text to feed to vcs
- [list] list the contents of the index
- [config] set, set-default or just display the current index url

[Unreleased]: https://github.com/stonier/vcs_extras/compare/0.1.1...HEAD
[0.1.1]: https://github.com/stonier/vcs_extras/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/stonier/vcs_extras/compare/c838ad46f0ffde6a9d030cbf0c91653bf5fd48e6...0.1.0
